@@ -8,7 +8,7 @@ import { FileLocker } from '@joplin/utils/fs';
 import { IpcMessageHandler, IpcServer, Message, newHttpError, sendMessage, SendMessageOptions, startServer, stopServer } from '@joplin/utils/ipc';
 import { BrowserWindow, Tray, WebContents, screen, App, nativeTheme } from 'electron';
 import bridge from './bridge';
-const url = require('url');
+import * as url from 'url';
 const path = require('path');
 const { dirname } = require('@joplin/lib/path-utils');
 const fs = require('fs-extra');
@@ -137,6 +137,24 @@ export default class ElectronAppWrapper {
 		return null;
 	}
 
+	private windowIdFromWebContents(webContents: WebContents): SecondaryWindowId|null {
+		const browserWindow = BrowserWindow.fromWebContents(webContents);
+		// Convert from electron IDs to Joplin IDs.
+		const targetElectronId = browserWindow.id;
+
+		if (this.win_?.id === targetElectronId) {
+			return 'default';
+		}
+
+		for (const [joplinId, { electronId }] of this.secondaryWindows_) {
+			if (electronId === targetElectronId) {
+				return joplinId;
+			}
+		}
+
+		return null;
+	}
+
 	public allAppWindows() {
 		const allWindowIds = [...this.secondaryWindows_.keys(), defaultWindowId];
 		return allWindowIds.map(id => this.windowById(id));
@@ -325,6 +343,14 @@ export default class ElectronAppWrapper {
 			}, 1000);
 		}
 
+		const sendWindowFocused = (focusedWebContents: WebContents) => {
+			const joplinId = this.windowIdFromWebContents(focusedWebContents);
+
+			if (joplinId !== null) {
+				this.win_.webContents.send('window-focused', joplinId);
+			}
+		};
+
 		const addWindowEventHandlers = (webContents: WebContents) => {
 			// will-frame-navigate is fired by clicking on a link within the BrowserWindow.
 			webContents.on('will-frame-navigate', event => {
@@ -357,6 +383,11 @@ export default class ElectronAppWrapper {
 			webContents.on('did-create-window', (event) => {
 				addWindowEventHandlers(event.webContents);
 			});
+
+			const onFocus = () => {
+				sendWindowFocused(webContents);
+			};
+			webContents.on('focus', onFocus);
 		};
 		addWindowEventHandlers(this.win_.webContents);
 
@@ -428,6 +459,10 @@ export default class ElectronAppWrapper {
 					this.win_.close();
 				}
 			});
+
+			if (window.isFocused()) {
+				sendWindowFocused(window.webContents);
+			}
 		});
 
 		// eslint-disable-next-line @typescript-eslint/no-explicit-any -- Old code before rule was applied
